#!/usr/bin/env bash

#
# Copyright (c) 2009 Peter Ljung <ljung.peter@gmail.com>
#
# Permission to use, copy, modify, and distribute this software for any
# purpose with or without fee is hereby granted, provided that the above
# copyright notice and this permission notice appear in all copies.
#
# THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
# WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
# MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
# ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
# WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
# ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
# OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
#

usage()
{
cat << EOF
usage: $0 OPTION

This script will install SwingCVS i.e. check for required dependencies and create a start script.

OPTIONS:
   -v   verbose/debug output
EOF
}

while getopts "hc:gvs" OPTION; do
  case $OPTION in
    v )  VERBOSE=1;;
    ? )  usage;exit 1;;
  esac
done

function check_dependency {
	which $1 &> /dev/null
	if [ "$?" = "2" ]; then
		echo "$1 is not found!"
		echo "Install or locate (include into PATH env) $1 before swingcvs can be run."
		exit
	fi
}

echo
echo "Required dependencies are checked ..."
check_dependency "bash"
check_dependency "sed"
check_dependency "awk"
check_dependency "cvs"
check_dependency "java"
echo "All dependencies was found!"

if [[ $VERBOSE ]]; then
	echo "Version numbers dependencies ..."
	bash -version
	awk -version
	cvs -version
	java -version
fi

echo "Create start script scvs.sh"
sed -e "s/<INSTALL_PATH>/${PWD//\//\\/}/g" 'script/scvs.skel' > 'scvs.sh'
chmod +x scvs.sh
echo
echo "Run SwingCVS using ./scvs.sh"
echo

